pitchtools.diatonic_interval_number_and_chromatic_interval_number_to_melodic_diatonic_interval
==============================================================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_interval_number_and_chromatic_interval_number_to_melodic_diatonic_interval.diatonic_interval_number_and_chromatic_interval_number_to_melodic_diatonic_interval
